@@ -22,6 +22,15 @@ def get_project_root_path() -> Path:
     return Path(__file__).parents[2].absolute()
 
 
+def get_package_root_path() -> Path:
+    """Get path of the package root.
+
+    Returns:
+        Path: Package root path
+    """
+    return Path(__file__).parents[0].absolute()
+
+
 def prepare_fhe_input(
     model_output: List,
     pre_processors: List[Tuple[PreProcessInput, List]],
